japanese_word_dict = {
    "main_window_current_filename": "現在のファイル名:",
    "main_window_current_filename_format": "現在のファイル名: {name}",
    "main_window_current_file": "ファイル",
    "main_window_open_folder": "フォルダーを開く",
    "main_window_exit": "終了",
    "main_window_tile_size": "サムネイルサイズ",
    "main_window_select_folder": "フォルダーを選択",
    "main_window_current_folder_format": "現在のフォルダー: {path}",
    "main_window_remove_undo_stack": "一時的な取り消しファイルを削除",
    # Language Menubar
    "menu_bar_language": "言語",
    "language_menu_bar_please_restart_messagebox": "再起動してください",
    "language_menu_bar_english": "英語",
    "language_menu_bar_traditional_chinese": "繁体字中国語",
    "language_menu_bar_chinese": "簡体字中国語",
    "language_menu_bar_koren": "韓国語",
    "language_menu_bar_japanese": "日本語",
    # Tip menu
    "main_window_tip_menu": "使用説明",
    "mouse_control_middle_tip": "マウスの中ボタンで移動できます",
    "main_window_mouse_tip_menu": "マウス操作",
    "main_window_keyboard_tip_menu": "キーボード操作",
    "mouse_control_left_tip": "マウス左ボタンで画像をクリックすると Deep zoom モードに入ります",
    "mouse_control_right_move_tip": "マウスの右ボタンを押したままにすると、サムネイルモードで複数の画像を選択できます",
    "keyboard_control_esc_tip": "Deep zoom モードでは ESC キーで終了できます",
    "keyboard_control_tile_arrow_up_tip": "サムネイルモードでは矢印キーの上で上に移動できます",
    "keyboard_control_tile_arrow_down_tip": "サムネイルモードでは矢印キーの下で下に移動できます",
    "keyboard_control_tile_arrow_left_tip": "サムネイルモードでは矢印キーの左で左に移動できます",
    "keyboard_control_tile_arrow_right_tip": "サムネイルモードでは矢印キーの右で右に移動できます",
    "keyboard_control_delete_tip": "サムネイルモードや Deep zoom モードでは Delete キーで画像を削除できます",
}
